==> custom_field-1.0.0-rc1.tar.gz: custom_field/src/Annotation/CustomFieldType.php <==
<?php

namespace Drupal\custom_field\Annotation;

use Drupal\Component\Annotation\Plugin;
use Drupal\Core\Annotation\Translation;

/**
 * Defines a Custom field Type item annotation object.
 *
 * @see \Drupal\custom_field\Plugin\CustomFieldTypeManager
 * @see plugin_api
 *
 * @Annotation
 */
class CustomFieldType extends Plugin {

  /**
   * The plugin ID.
   *
   * @var string
   */
  public string $id;

  /**
   * The label of the plugin.
   *
   * @var \Drupal\Core\Annotation\Translation
   *
   * @ingroup plugin_translatable
   */
  public Translation $label;

  /**
   * A short human readable description for the customfield type.
   *
   * @var \Drupal\Core\Annotation\Translation
   *
   * @ingroup plugin_translatable
   */
  public Translation $description;

  /**
   * The default value for the check empty field setting. Defaults to FALSE
   *
   * @see \Drupal\custom_field\Plugin\Field\FieldType\CustomItem
   *
   * @var boolean
   *
   * @ingroup plugin_translatable
   */
  public bool $check_empty = FALSE;

  /**
   * Flag to determine if this type should never be checked to determine if
   * the customfield row is empty. This will override $check_empty.
   *
   * @see \Drupal\custom_field\Plugin\CustomFieldType\Uuid
   *
   * @var boolean
   *
   * @ingroup plugin_translatable
   */
  public bool $never_check_empty = FALSE;

  /**
   * The category under which the field type should be listed in the UI.
   *
   * @ingroup plugin_translatable
   *
   * @var string
   */
  public string $category = 'general';

  /**
   * An array of data types the widget supports.
   *
   * @var array
   */
  public array $data_types = [];

}

==> custom_field-2.0.0-rc1.tar.gz: custom_field/src/Annotation/CustomFieldType.php <==
<?php

namespace Drupal\custom_field\Annotation;

use Drupal\Component\Annotation\Plugin;
use Drupal\Core\Annotation\Translation;

/**
 * Defines a Custom field Type item annotation object.
 *
 * @see \Drupal\custom_field\Plugin\CustomFieldTypeManager
 * @see plugin_api
 *
 * @Annotation
 */
class CustomFieldType extends Plugin {

  /**
   * The plugin ID.
   *
   * @var string
   */
  public string $id;

  /**
   * The label of the plugin.
   *
   * @var \Drupal\Core\Annotation\Translation
   *
   * @ingroup plugin_translatable
   */
  public Translation $label;

  /**
   * A short human readable description for the customfield type.
   *
   * @var \Drupal\Core\Annotation\Translation
   *
   * @ingroup plugin_translatable
   */
  public Translation $description;

  /**
   * The default value for the check empty field setting.
   *
   * @var bool
   *
   * @ingroup plugin_translatable
   * @see \Drupal\custom_field\Plugin\Field\FieldType\CustomItem
   */
  public bool $check_empty = FALSE;

  /**
   * Flag to restrict this type from empty row checking.
   *
   * @var bool
   *
   * @ingroup plugin_translatable
   * @see \Drupal\custom_field\Plugin\CustomField\FieldType\Uuid
   */
  public bool $never_check_empty = FALSE;

  /**
   * The category under which the field type should be listed in the UI.
   *
   * @var string
   *
   * @ingroup plugin_translatable
   */
  public string $category = 'general';

  /**
   * The plugin_id of the default widget for this field type.
   *
   * This widget must be available whenever the field type is available (i.e.
   * provided by the field type module, or by a module the field type module
   * depends on).
   *
   * @var string
   */
  public $default_widget;

  /**
   * The plugin_id of the default formatter for this field type.
   *
   * This formatter must be available whenever the field type is available (i.e.
   * provided by the field type module, or by a module the field type module
   * depends on).
   *
   * @var string
   */
  public $default_formatter;

}
